#
# spec file for package python-googlemaps
#
# Copyright (c) 2025 SUSE LLC
#
# All modifications and additions to the file contributed by third parties
# remain the property of their copyright owners, unless otherwise agreed
# upon. The license for this file, and modifications and additions to the
# file, is the same license as for the pristine package itself (unless the
# license for the pristine package is not an Open Source License, in which
# case the license is the MIT License). An "Open Source License" is a
# license that conforms to the Open Source Definition (Version 1.9)
# published by the Open Source Initiative.

# Please submit bugfixes or comments via https://bugs.opensuse.org/
#


%define skip_python2 1
Name:           python-googlemaps
Version:        4.7.3
Release:        2.1
Summary:        Python client library for Google Maps API Web Services
License:        Apache-2.0
Group:          Development/Languages/Python
URL:            https://github.com/googlemaps/google-maps-services-python
Source:         https://github.com/googlemaps/google-maps-services-python/archive/v%{version}.tar.gz#/googlemaps-%{version}.tar.gz
BuildRequires:  %{python_module pip}
BuildRequires:  %{python_module pytest}
BuildRequires:  %{python_module requests >= 2.20.0}
BuildRequires:  %{python_module responses >= 0.3}
BuildRequires:  %{python_module setuptools}
BuildRequires:  %{python_module wheel}
BuildRequires:  fdupes
BuildRequires:  python-rpm-macros
Requires:       python-requests >= 2.20.0
BuildArch:      noarch
%python_subpackages

%description
Geocoding, reverse geocoding, driving directions, and local search in
Python via Google.

%prep
%setup -q -n google-maps-services-python-%{version}
# do not require coverage
sed -i 's/--cov.*$//' setup.cfg

%build
%pyproject_wheel

%install
%pyproject_install
%python_expand %fdupes %{buildroot}%{$python_sitelib}

%check
# the tests catch ApiError, which means they have to connect to the actual GoogleMaps (and they get no internet for it)
%pytest -k "not (test_elevation_along_path_single or test_transit_without_time)"

%files %{python_files}
%license LICENSE
%doc README.md CHANGELOG.md
%{python_sitelib}/googlemaps
%{python_sitelib}/googlemaps-%{version}.dist-info

%changelog
* Tue Jun 17 2025 Steve Kowalik <steven.kowalik@suse.com>
- Use pyproject macros to build and install.
* Thu Jan 19 2023 Andrea Manzini <andrea.manzini@suse.com>
- Update to 4.7.3
  * correct lazy attribute inside logger
  * Adds support for Address Validation API
  * Geocode by place id
  * make Places textsearch query parameter optional
* Tue Jun  9 2020 Marketa Calabkova <mcalabkova@suse.com>
- Update to 4.4.1
  * Add support for Maps Static API
  * Adding support for passing in experience_id to Client class
  * Python 2 is no longer supported
  * Removed place fields: alt_id, id, reference, and scope.
  * APIError.__str__ should always return a str
  * Tests for distribution tar as part of CI
  * Support for subfields such as geometry/location and geometry/viewport in Places.
  * Switched build system to use nox, pytest, and codecov.
* Fri Mar 15 2019 Tomáš Chvátal <tchvatal@suse.com>
- Update to 3.0.2:
  * no upstream changelog
* Tue Dec  4 2018 Matej Cepl <mcepl@suse.com>
- Remove superfluous devel dependency for noarch package
* Wed May 16 2018 toddrme2178@gmail.com
- Update to 2.5.1
  * Mark places radar search as deprecated.
  * Fix places autocomplete param, type -> types.
  * Add strictbounds param to places API.
  * Added geolocation API
  * Allow a requests.Session object to be passed into Client
  * Support POST requests in client.
  * Fix issue with extra_params + threading.
  * Provide a way to add extra params to any request.
  * Add test for nearest roads.
  * Implement nearestRoads in the Google Maps Roads API
  * Update instructions for API keys and client IDs.
  * Allow multiple values per type in components.
  * roads: handle {} response
  * Changed the requirement from "no API key" to "has client ID"
  * Adding channel support for Maps for Work users of this library
  * Added missing Places API features
  * Trim extraneous chars from latlngs.
  * In elevations API, automatically use encoded polylines if shorter
  * Add reverse geocoding my place_id
  * Better traffic_model docstrings.
  * Give some of the ambiguous places method names more meaningful names.
  * Unify lat/lng conversions.
  * Added Places API.
  * Use utcnow to generate timestamp
  * Add traffic_model parameter
  * Default rate limit to 10 queries per second.
  * Allow kwargs for requests to be passed into the maps client
- Implement single-spec version
- Complete spec file rewrite
* Sun Oct 18 2009 alexandre@exatati.com.br
- Update to 1.0.2;
- Fixed Requires tag in spec file (added python-simplejson).
* Thu Oct  1 2009 alexandre@exatati.com.br
- Update to 1.0.1;
- Building as noarch for openSUSE >= 11.2.
* Tue Sep 22 2009 alexandre@exatati.com.br
- Initial package (0.1) for openSUSE.
